local WaterMill = ...

WaterMillPrefix = "WATER_MILL"

local myMonument = {
    Id = WaterMillPrefix .. "_MONUMENT"
}

if (foundation.getGameVersion == nil or version.cmp(foundation.getGameVersion(), "1.6") < 0) then
    WaterMill:log("Hello World: version 1.5")
    myMonument.DataType = "MONUMENT"
    WaterMillTagBehaviorWork = "WORK_BEHAVIOR"
    _CoreBuildingZone = { Polygon = polygon.createRectangle( {4, 8} ) } 
    _WheelBuildingZone = { Polygon = polygon.createRectangle( {4, 6} ) } 
else
    WaterMill:log("Hello World: version " .. foundation.getGameVersion())
    myMonument.DataType = "BUILDING"
    myMonument.AssetCoreBuildingPart = WaterMillPrefix .. "_CORE_BUILDING_PART"
    WaterMillTagBehaviorWork = "BEHAVIOR_WORK"
    _CoreBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {4, 8} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
    }}
    _WheelBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {4, 6} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
    }}
    WaterMill:registerEnumValue ("BUILDING_PART_TYPE", "EXTENSION")
end

-- Apply building asset processor
WaterMill:registerAssetProcessor("models/waterMill.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

-- Particle system
WaterMill:dofile("scripts/flow.lua")

-- Register all water mill building parts and their properties
WaterMill:dofile("scripts/buildings.lua")

myMonument.Name = WaterMillPrefix .. "_SET_NAME"
myMonument.Description = WaterMillPrefix .. "_SET_DESC"
myMonument.BuildingType = "MONUMENT"
 

myMonument.BuildingPartSetList = {
        {
            Name = "PRODUCTION_CORE",
	    BuildingPartList = {
		WaterMillPrefix .. "_CORE_FLOUR_PART",
		WaterMillPrefix .. "_CORE_TEXTILE_PART",
		WaterMillPrefix .. "_CORE_PLANKS_PART"
            }
        },
        { 
            Name = "WHEEL",
	    BuildingPartList = {
		WaterMillPrefix .. "_EXTENSION_LEFT_BANK_PART",
		WaterMillPrefix .. "_EXTENSION_RIGHT_BANK_PART"
	    }
        }
    } 
WaterMill:registerAssetId("models/waterMill.fbx/Materials/toitJaune", WaterMillPrefix .. "_YELLOW_ROOF_MATERIAL")
WaterMill:registerAssetId("models/waterMill.fbx/Materials/toitVert", WaterMillPrefix .. "_GREEN_ROOF_MATERIAL")
WaterMill:registerAssetId("models/waterMill.fbx/Materials/toitBrun", WaterMillPrefix .. "_BROWN_ROOF_MATERIAL")
WaterMill:registerAssetId("models/waterMill.fbx/Materials/toitBleu", WaterMillPrefix .. "_BLUE_ROOF_MATERIAL")
WaterMill:registerAssetId("models/waterMill.fbx/Materials/toitRouge", WaterMillPrefix .. "_RED_ROOF_MATERIAL")
myMonument.MaterialSetList = {
            {
                SetName = WaterMillPrefix .. "_YELLOW_ROOF", -- default materials
                MaterialList = {
                    WaterMillPrefix .. "_YELLOW_ROOF_MATERIAL"
                }           
            },
            {
                SetName = WaterMillPrefix .. "_GREEN_ROOF", -- default materials
                MaterialList = {
                    WaterMillPrefix .. "_GREEN_ROOF_MATERIAL"
                }           
            },
            {
                SetName = WaterMillPrefix .. "_BROWN_ROOF", -- default materials
                MaterialList = {
                    WaterMillPrefix .. "_BROWN_ROOF_MATERIAL"
                }           
            },
            {
                SetName = WaterMillPrefix .. "_BLUE_ROOF", -- default materials
                MaterialList = {
                    WaterMillPrefix .. "_BLUE_ROOF_MATERIAL"
                }           
            },
            {
                SetName = WaterMillPrefix .. "_RED_ROOF", -- default materials
                MaterialList = {
                    WaterMillPrefix .. "_RED_ROOF_MATERIAL"
                }           
            }
}
myMonument.RequiredPartList = {
		-- Necessarily a list of 'MONUMENT_REQUIRED_PART_PAIR', no need to specify the DataType of each element of the list
		{ Category = "CORE", Quantity = 1 },
		{ Category = "EXTENSION", Quantity = 1 }
    }
myMonument.IsEditable = true
-- Register the water mill monument
WaterMill:register(myMonument)